<!DOCTYPE TS><TS>
<defaultcodec></defaultcodec>
<context>
    <name></name>
    <message>
        <source>Error in config.py:</source>
        <translation>Błąd w pliku konfiguracyjnym config.py:</translation>
    </message>
    <message>
        <source>Error when running plugin:</source>
        <translation>Błąd podczas uruchamiania wtyczki:</translation>
    </message>
    <message>
        <source>Unable to load file.</source>
        <translation>Nie można załadować pliku.</translation>
    </message>
    <message>
        <source>Invalid file format.</source>
        <translation>Nieprawidłowy format pliku.</translation>
    </message>
    <message>
        <source>Unable to save file.</source>
        <translation>Nie można zapisać pliku.</translation>
    </message>
    <message>
        <source>Unable to parse XML:</source>
        <translation>Błąd składni XML:</translation>
    </message>
    <message>
        <source>Unrecognised encoding.</source>
        <translation>Niepoprawne kodowanie.</translation>
    </message>
    <message>
        <source>Missing answer on line:</source>
        <translation>Brakująca odpowiedź w lini:</translation>
    </message>
    <message>
        <source>Unable to load database.
Creating tmp file.</source>
        <translation>Nie można załadować pliku bazy danych.
Tworzenie pliku tymczasowego &quot;tmp&quot;.</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>File exists:</source>
        <translation>Plik istnieje:</translation>
    </message>
    <message>
        <source>&amp;Overwrite</source>
        <translation>&amp;Zastąp</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Anuluj</translation>
    </message>
    <message>
        <source>Removed duplicates: </source>
        <translation>Usunięte duplikaty:</translation>
    </message>
    <message>
        <source>There are cards with different answers for question:

</source>
        <translation>Istnieją już karty z innymi odpowiedziami na pytanie:</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>&amp;Scal i edytuj</translation>
    </message>
    <message>
        <source>&amp;Don&apos;t merge</source>
        <translation>&amp;Nie scalaj</translation>
    </message>
    <message>
        <source>Done!</source>
        <translation>Zakończono!</translation>
    </message>
    <message>
        <source>You don&apos;t remember this card yet.</source>
        <translation>Karta nie została jeszcze zapamiętana.</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
        <translation>Informacja znana, jednak niezapamiętana.</translation>
    </message>
    <message>
        <source> Show it less often.</source>
        <translation> Wyświetlaj rzadziej.</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this card now,</source>
        <translation>Informacja zapamiętana</translation>
    </message>
    <message>
        <source> and will probably remember it for a few days.</source>
        <translation> i pozostanie w pamięci przez około 2 dni.</translation>
    </message>
    <message>
        <source>You have forgotten this card completely.</source>
        <translation>Karta niezapamiętana.</translation>
    </message>
    <message>
        <source>Barely correct answer. The interval was way too long.</source>
        <translation>Odpowiedź zawierała błędy. Przerwa między powtórkami była zbyt długa.</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort.</source>
        <translation>Poprawna odpowiedź udzielona z wielkim wysiłkiem.</translation>
    </message>
    <message>
        <source> The interval was probably too long.</source>
        <translation> Przerwa między powtórkami była zbyt długa.</translation>
    </message>
    <message>
        <source>Correct answer, with some effort.</source>
        <translation>Poprawna odpowiedź udzielona bez znaczącego wysiłku.</translation>
    </message>
    <message>
        <source> The interval was probably just right.</source>
        <translation> Przerwa między powtórkami jest odpowiednia.</translation>
    </message>
    <message>
        <source>Correct answer, but without any</source>
        <translation>Poprawna odpowiedź udzielona</translation>
    </message>
    <message>
        <source> difficulties. The interval was probably too short.</source>
        <translation> z łatwością. Przerwa między powtórkami była zbyt krótka.</translation>
    </message>
</context>
<context>
    <name>AboutDlg</name>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Main author: Peter Bienstman

</source>
        <translation>Autor programu: Peter Bienstman </translation>
    </message>
    <message>
        <source> More info: http://mnemosyne-proj.sourceforge.net
</source>
        <translation type="obsolete">Dodatkowe informacje można uzyskać na stronie: http://mnemosyne-proj.sourceforge.net</translation>
    </message>
    <message>
        <source>More info: http://mnemosyne-proj.org
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutFrm</name>
    <message>
        <source>About</source>
        <translation>Informacje</translation>
    </message>
</context>
<context>
    <name>ActivateCategoriesFrm</name>
    <message>
        <source>Activate categories</source>
        <translation>Aktywuj kategorie</translation>
    </message>
    <message>
        <source>Select the categories to activate:</source>
        <translation>Zaznacz kategorie do aktywacji:</translation>
    </message>
    <message>
        <source>Activate none</source>
        <translation>Dezaktywuj wszystkie</translation>
    </message>
    <message>
        <source>Activate all</source>
        <translation>Aktywuj wszystkie</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Anuluj</translation>
    </message>
</context>
<context>
    <name>AddItemsDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;domyślny&gt;</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Abandon current card?</source>
        <translation>Porzucić kartę?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Tak</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nie</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Pytanie:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Odpowiedź:</translation>
    </message>
    <message>
        <source>Written form:</source>
        <translation>Forma pisemna:</translation>
    </message>
    <message>
        <source>Translation:</source>
        <translation>Tłumaczenie:</translation>
    </message>
    <message>
        <source>Card is already in database.
</source>
        <translation>Dana karta znajduje się już w bazie.</translation>
    </message>
    <message>
        <source>Duplicate not added.</source>
        <translation>Duplikat nie został dodany.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>There are different answers for</source>
        <translation>W bazie znajdują się inne odpowiedzi udzielone na</translation>
    </message>
    <message>
        <source> this question:

</source>
        <translation>pytanie:</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>&amp;Scal i edytuj</translation>
    </message>
    <message>
        <source>&amp;Add as is</source>
        <translation>&amp;Dodaj nie zmienione</translation>
    </message>
    <message>
        <source>&amp;Do not add</source>
        <translation>&amp;Nie dodawaj</translation>
    </message>
</context>
<context>
    <name>AddItemsFrm</name>
    <message>
        <source>Add cards</source>
        <translation>Dodaj kartę</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategoria:</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Pytanie:</translation>
    </message>
    <message>
        <source>Pronunciation:</source>
        <translation>Wymowa:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Odpowiedź:</translation>
    </message>
    <message>
        <source>Add &amp;vice versa too</source>
        <translation>Dodaj &amp;odwrotną</translation>
    </message>
    <message>
        <source>Alt+V</source>
        <translation>Alt+V</translation>
    </message>
    <message>
        <source>Select initial grade:</source>
        <translation>Wybierz ocenę początkową:</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>You don&apos;t remember this item yet or forgot it.</source>
        <translation>Informacja niezapamiętana lub zapomniana.</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but the item is getting more familiar.</source>
        <translation>Informacja znana, jednak niezapamiętana.</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this item now, and will probably remember it for a few days.</source>
        <translation>Informacja zapamiętana i pozostanie w pamięci przez około 2 dni.</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort. The interval was probably too long</source>
        <translation>Poprawna odpowiedź udzielona z wielkim wysiłkiem. Przerwa między powtórkami była zbyt długa.</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>Ctrl+4</source>
        <translation>Ctrl+4</translation>
    </message>
    <message>
        <source>Correct answer, with some effort. The interval was probably just right.</source>
        <translation>Poprawna odpowiedź udzielona bez znaczącego wysiłku. Przerwa między powtórkami jest odpowiednia.</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>Ctrl+5</source>
        <translation>Ctrl+5</translation>
    </message>
    <message>
        <source>Correct answer, but without any difficulties. The interval was probably too short.</source>
        <translation>Poprawna odpowiedź udzielona z łatwością.Przerwa między powtórkami była za krótka.</translation>
    </message>
    <message>
        <source>Type question and answer, then pick initial grade.</source>
        <translation>Wpisz pytanie oraz odpowiedź, a następnie wybierz ocenę.</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation type="obsolete">&amp;Podgląd</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Wy&amp;jście</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChangeCategoryFrm</name>
    <message>
        <source>Change category</source>
        <translation>Zmień kategorię</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategoria:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Anuluj</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>ConfigurationFrm</name>
    <message>
        <source>Mnemosyne configuration</source>
        <translation>Preferencje</translation>
    </message>
    <message>
        <source>Hover with the mouse over the buttons to get extra information.</source>
        <translation>Aby uzyskać więcej informacji na temat przycisku zatrzymaj nad nim kursor myszy.</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Wygląd</translation>
    </message>
    <message>
        <source>Set Q/A font</source>
        <translation>Ustaw czcionkę pytań i odpowiedzi</translation>
    </message>
    <message>
        <source>Set the font used when showing single questions and answers</source>
        <translation>Ustaw czcionkę, przy pomocy której wyświetlane są pytania i odpowiedzi.</translation>
    </message>
    <message>
        <source>Set list font</source>
        <translation>Ustaw czcionkę edytora zestawu kart</translation>
    </message>
    <message>
        <source>Set the font used when showing the list of all the cards in the deck</source>
        <translation>Ustaw czcionkę, przy pomocy której wyświetlany jest tekst w edytorze zestawu kart</translation>
    </message>
    <message>
        <source>Increase size of non-latin characters by</source>
        <translation>Zwiększ rozmiar znaków pochodzenia innego niż łacińskie o</translation>
    </message>
    <message>
        <source>Sometimes complex glyphs are hard to read at the default latin font size</source>
        <translation>Korzystanie z domyślnego rozmiaru czcionki łacińskiej może powodować, że w niektóre złożne znaki języków obcych będą trudne do odczytania</translation>
    </message>
    <message>
        <source>point(s)</source>
        <translation>punkt(y/ów)</translation>
    </message>
    <message>
        <source>Log uploading</source>
        <translation>Przesyłanie dziennika</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>Przesyłaj anonimowe dane dziennika powtórek</translation>
    </message>
    <message>
        <source>Share anonymous statistics to contribute to memory research</source>
        <translation>Udostępnij anonimowe statystyki do celów badań nad pamięcią</translation>
    </message>
    <message>
        <source>Duplicate handling</source>
        <translation>Obsługa duplikatów</translation>
    </message>
    <message>
        <source>Check for duplicates when adding new cards</source>
        <translation>Sprawdzaj czy dodawana karta już istnieje</translation>
    </message>
    <message>
        <source>Allow duplicates in different categories</source>
        <translation>Zezwalaj na duplikację kart jeśli znajdują się w oddzielnych kategoriach</translation>
    </message>
    <message>
        <source>Repetition process</source>
        <translation>Przebieg powtórek</translation>
    </message>
    <message>
        <source>Number of grade 0 cards to learn at once:</source>
        <translation>Ilość przeznaczonych do zapamiętania kart, które otrzymały ocenę 0:</translation>
    </message>
    <message>
        <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
        <translation>Uwaga: jest to ogólna ilość przeznaczonych do zapamiętania kart, które otrzymały ocenę 0</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation>Domyślne</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Anuluj</translation>
    </message>
    <message>
        <source>Learn new cards in random order</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditItemFrm</name>
    <message>
        <source>Edit card</source>
        <translation>Edytuj kartę</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategoria:</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Pytanie:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Odpowiedź:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Podgląd</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Anuluj</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>EditItemsDlg</name>
    <message>
        <source>Please wait...</source>
        <translation>Proszę czekać...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Edycja</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Podgląd</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Add vice versa</source>
        <translation>Dodaj &amp;odwrotną</translation>
    </message>
    <message>
        <source>S&amp;tatistics</source>
        <translation>S&amp;tatystyki</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Usuń</translation>
    </message>
    <message>
        <source>&amp;Change category</source>
        <translation>&amp;Zmień kategorię</translation>
    </message>
    <message>
        <source>Add &amp;vice versa</source>
        <translation>Dodaj &amp;odwrotną</translation>
    </message>
    <message>
        <source>Add vice versa of these cards?</source>
        <translation>Czy dodać odwrotności wybranych kart?</translation>
    </message>
    <message>
        <source>Add vice versa of this card?</source>
        <translation>Czy dodać odwrotność karty?</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>

This could create duplicates if the vice </source>
        <translation>

W wypadku istnienia odwrotności kart </translation>
    </message>
    <message>
        <source>versas are already present, 
so you might want to run </source>
        <translation>wybrana czynność spowoduje powstanie duplikatów. 
Konieczne może być</translation>
    </message>
    <message>
        <source>clean duplicates&apos; afterwards.</source>
        <translation>ich usunięcie.</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Tak</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nie</translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation>Ocena:</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation>Łatwość:</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation>Powtórki:</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation>Pomyłki:</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation>Liczba dni, które upłynęły od ostatniej powtórki:</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation>Liczba dni pozostałych do rozpoczęcia powtórki:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Delete these cards?</source>
        <translation>Czy usunąć wybrane karty?</translation>
    </message>
    <message>
        <source>Delete this card?</source>
        <translation>Czy usunąć wybraną kartę?</translation>
    </message>
    <message>
        <source>The text you entered was not found.</source>
        <translation>Wprowadzony tekst nie został odnaleziony.</translation>
    </message>
    <message>
        <source>&amp;Find again</source>
        <translation>&amp;Szukaj ponownie</translation>
    </message>
    <message>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Szukaj</translation>
    </message>
    <message>
        <source>Alt+F</source>
        <translation type="obsolete"></translation>
    </message>
</context>
<context>
    <name>EditItemsFrm</name>
    <message>
        <source>Question</source>
        <translation>Pytanie</translation>
    </message>
    <message>
        <source>Answer</source>
        <translation>Odpowiedź</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategoria</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>Edytuj zestaw kart</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Znajdź</translation>
    </message>
    <message>
        <source>To edit a card, right-click on it.</source>
        <translation>Kliknij prawym przyciskiem myszy aby edytować kartę.</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Za&amp;mknij</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <source>Alt+F</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>All Files (*);;</source>
        <translation>Wszytkie pliki (*);;</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksportuj</translation>
    </message>
</context>
<context>
    <name>ExportFrm</name>
    <message>
        <source>Export to file</source>
        <translation>Eksportuj do pliku</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>Format pliku:</translation>
    </message>
    <message>
        <source>File to export to:</source>
        <translation>Eksportuj do:</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>&amp;Przeglądaj</translation>
    </message>
    <message>
        <source>Categories to export:</source>
        <translation>Eksportuj kategorie:</translation>
    </message>
    <message>
        <source>&amp;Select all</source>
        <translation>&amp;Zaznacz wszystkie</translation>
    </message>
    <message>
        <source>Reset learning data on export</source>
        <translation>Podczas eksportowania usuń dane dotyczące powtórek</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Anuluj</translation>
    </message>
</context>
<context>
    <name>ImportDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;domyślny&gt;</translation>
    </message>
    <message>
        <source>All Files (*);;</source>
        <translation>Wszytkie pliki (*);;</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importuj</translation>
    </message>
</context>
<context>
    <name>ImportFrm</name>
    <message>
        <source>Import from file</source>
        <translation>Importuj z pliku</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>Format pliku:</translation>
    </message>
    <message>
        <source>File to import from:</source>
        <translation>Wybierz plik, z którego zostaną zaimportowane dane:</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>&amp;Przeglądaj</translation>
    </message>
    <message>
        <source>Put cards without category into this category:</source>
        <translation>Karty pozbawione kategorii przypisz do kategorii:</translation>
    </message>
    <message>
        <source>Note: all cards will be added to the current database.</source>
        <translation>Uwaga: wszystkie karty zostaną dodane do obecnie wykorzystywanej bazy.</translation>
    </message>
    <message>
        <source>Reset learning data on import</source>
        <translation>Podczas importowania, usuń dane dotyczące powtórek</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Anuluj</translation>
    </message>
</context>
<context>
    <name>MainDlg</name>
    <message>
        <source>Mnemosyne databases (*.mem)</source>
        <translation>baza danych programu Mnemosyne (*.mem)</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nowy</translation>
    </message>
    <message>
        <source>Please wait...</source>
        <translation>Proszę czekać...</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Delete current card?</source>
        <translation>Czy na pewno chcesz usunąć zaznaczoną kartę?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Tak</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nie</translation>
    </message>
    <message>
        <source>Returns in </source>
        <translation>Karta zostanie wyświetlona ponownie w ciągu</translation>
    </message>
    <message>
        <source> day(s).</source>
        <translation> dni(a).</translation>
    </message>
    <message>
        <source>Next repetition: today.</source>
        <translation>Kolejna powtórka: dzisiaj.</translation>
    </message>
    <message>
        <source>Next repetition: tomorrow.</source>
        <translation>Kolejna powtórka: jutro.</translation>
    </message>
    <message>
        <source>Next repetition in </source>
        <translation>Kolejna powtórka za najbliższe</translation>
    </message>
    <message>
        <source> days.</source>
        <translation> dni.</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Pytanie z kategorii:</translation>
    </message>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;domyślny&gt;</translation>
    </message>
    <message>
        <source>Show &amp;answer</source>
        <translation type="obsolete">Pokaż &amp;odpowiedź</translation>
    </message>
    <message>
        <source>Learn ahead of schedule</source>
        <translation>Nauka przed wyznaczonym czasem</translation>
    </message>
    <message>
        <source>Pick days until next repetition:</source>
        <translation>Wybierz liczbę dni pozostałych do następnej powtórki:</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation>Oceń odpowiedź:</translation>
    </message>
    <message>
        <source>Scheduled: </source>
        <translation>Zaplanowanych:</translation>
    </message>
    <message>
        <source>Not memorised: </source>
        <translation>Niezapamiętanych:</translation>
    </message>
    <message>
        <source>All: </source>
        <translation>Wszystkich: </translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation type="unfinished">Pokaż odpowiedź</translation>
    </message>
</context>
<context>
    <name>MainFrm</name>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Pytanie:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Odpowiedź:</translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation>Pokaż odpowiedź</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation>Oceń odpowiedź:</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nowy</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Otwórz...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Zapisz</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Zapisz &amp;jako...</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Za&amp;mknij</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Informacje</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Informacje</translation>
    </message>
    <message>
        <source>Add cards</source>
        <translation>Dodaj kartę</translation>
    </message>
    <message>
        <source>&amp;Add cards</source>
        <translation>&amp;Dodaj kartę</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>Act&amp;ivate categories</source>
        <translation type="obsolete">Akt&amp;ywuj kategorie</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>Edytuj zestaw kart</translation>
    </message>
    <message>
        <source>Edit &amp;deck</source>
        <translation>Edytuj zestaw &amp;kart</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>&amp;Importuj</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksportuj</translation>
    </message>
    <message>
        <source>Show &amp;toolbar</source>
        <translation>Pokaż &amp;pasek narzędzi</translation>
    </message>
    <message>
        <source>Edit current card</source>
        <translation>Edytuj kartę</translation>
    </message>
    <message>
        <source>&amp;Edit current card</source>
        <translation>&amp;Edytuj kartę</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Delete current card</source>
        <translation>Usuń kartę</translation>
    </message>
    <message>
        <source>&amp;Delete current card</source>
        <translation>&amp;Usuń kartę</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <source>&amp;Clean duplicates</source>
        <translation>&amp;Usuń duplikaty</translation>
    </message>
    <message>
        <source>&amp;Configure Mnemosyne</source>
        <translation>&amp;Ustawienia Mnemosyne</translation>
    </message>
    <message>
        <source>Getting started</source>
        <translation>Wprowadzenie</translation>
    </message>
    <message>
        <source>&amp;Getting started</source>
        <translation>&amp;Wprowadzenie</translation>
    </message>
    <message>
        <source>Down, Down</source>
        <translation>W dół</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Wprowadź</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Powrót</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Spacja</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Show statistics</source>
        <translation>Wyświetl statystyki</translation>
    </message>
    <message>
        <source>Show s&amp;tatistics</source>
        <translation>Wyświetl s&amp;tatystyki</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Tip of the day</source>
        <translation>Porada dnia</translation>
    </message>
    <message>
        <source>&amp;Tip of the day</source>
        <translation>&amp;Porada dnia</translation>
    </message>
    <message>
        <source>Main toolbar (Mnemosyne)</source>
        <translation>Główny pasek narzędzi (Mnemosyne)</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Plik</translation>
    </message>
    <message>
        <source>&amp;Deck</source>
        <translation>&amp;Zestaw</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ustawienia</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <source>Activate cate&amp;gories</source>
        <translation>Aktywuj kate&amp;gorie</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
</context>
<context>
    <name>PreviewItemDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;domyślny&gt;</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Pytanie:</translation>
    </message>
</context>
<context>
    <name>PreviewItemFrm</name>
    <message>
        <source>Preview card</source>
        <translation>Podgląd karty</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Pytanie:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Odpowiedź:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
</context>
<context>
    <name>ProductTourFrm</name>
    <message>
        <source>Getting started</source>
        <translation>Wprowadzenie</translation>
    </message>
    <message>
        <source>Greetings!

I am Mnemosyne, a type of butterfly named after the Greek goddess of Memory. 

I can make it more efficient for you to memorise and remember answers to questions, by helping you focus on the cards you&apos;re most likely to forget and by not wasting your time on things you know well.

For that, I&apos;ll decide when to ask you the questions, and you&apos;ll need to rate how well you remember the answers.

Let&apos;s look at the meaning of these ratings now.</source>
        <translation>Witaj!

Jestem programem Mnemosyne nazwanym tak od imienia greckiej boginii pamięci.

Pomagam w zapamiętywaniu wyświetlając pytania odnośnie tylko tych informacji, które mogą zostać zapomniane.

Jednak abym mógł wykonywać swoje zadanie dobrze ważne jest abyś oceniał swoje odpowiedzi według proponowanej przeze mnie skali.

Przyjrzyjmy się jej bliżej.</translation>
    </message>
    <message>
        <source>Introduction</source>
        <translation>Wprowadzenie</translation>
    </message>
    <message>
        <source>Grades range from 0 to 5.

Grades 0 and 1 are used if you don&apos;t know the answer yet, or if you have forgotten it. A card with grade 1 is starting to get more familiar than one with grade 0, and will be repeated less often.

I will keep on asking you these questions until you give them a grade 2 or higher (the exact grade doesn&apos;t matter). Grade 2 basically means that you think you&apos;ll be able to remember the card for at least one or two days. It signals the transition between short and long term memory.

I will schedule this card at some future date, when I think you&apos;ll still be able to remember it with some effort, without having forgotten it completely. This is the most efficient for the learning process.</source>
        <translation>Oceny mieszczą się w zakresie od 0 do 5.

Przy pomocy 0 i 1 oznaczane są karty zawierające informacje nieznane lub niezapamiętane. Kartę z oceną 1 traktuję jako już znaną, lecz jeszcze niezapamiętaną.

Dlatego pytania, na które udzielone odpowiedzi otrzymają ocenę 0 oraz 1 będę zadawał dopóki dopóty otrzymają ocenę wyższą, np. 2. Dwójka oznacza, że zapamiętasz kartę na czas około 2 dni. Ocena ta sygnalizuje, że informacja przechodzi z pamięci krótkotrwałej do długotrwałej.

Zaplanuję powtórkę na dzień, w którym jak sądzę będziesz jeszcze pamiętał tę kartę, choć przypomnienie jej może sprawić Ci już kłopoty. Takie rozplanowywanie jest jednym z najbardziej efektywnych sposobów przyswajania wiedzy.</translation>
    </message>
    <message>
        <source>Grades 0-2</source>
        <translation>Oceny od 0 do 2</translation>
    </message>
    <message>
        <source>If in the future I ask you the question too soon, and you&apos;re able to remember it without any effort, you rate the card a 5. I&apos;ll take this into account by waiting a lot longer before asking you this question again.

If I get it just right, so that you remember it, albeit with some effort, you use grade 4.

If on the other hand it takes you significant effort to remember the answer, and you think I&apos;ve waited too long to ask you this question, then rate the card 3.

If you fail to remember it altogether, rate it either 0 or 1, and I&apos;ll keep on asking you this question until you think you&apos;ll be able to remember it again for a few days.</source>
        <translation>Jeśli zdarzy się, że bez kłopotu udzielisz odpowiedzi na zadane pytanie to oceń kartę na 5. Oznacza to, że pytanie zadałem zbyt wcześnie, dlatego następną powtórkę zaplanuję na dalszy termin.

Z drugiej strony, jeśli w udzielenie odpowiedzi włożyłeś nieco wysiłku, oceń ją na 4.

Pozostała jeszcze ocena 3, z której skorzystaj gdy udzielenie odpowiedzi sprawia ci wiele kłopotów i uważasz, że czekałem zbyt długo z zadaniem pytania.

Jeśli całkiem zapomniałeś jak brzmi odpowiedź na dane pytanie to oceń ją na 0 lub 1. Wtedy daną informację będę powtarzał do momentu, aż otrzyma ocenę wyższą.</translation>
    </message>
    <message>
        <source>Grades 3-5</source>
        <translation>Oceny od 3 do 5</translation>
    </message>
    <message>
        <source>If you&apos;re into statistics, I can keep detailed logs of your revisions.

Not only that, but if you want, I can upload transparently a completely anonymous version of these logs to a central site for analysis, so that you can help making me better. In this way, you also contribute to scientific research on long-term memory.

Uncheck the following box if you do not want to do this.</source>
        <translation>Jeśli lubisz śledzić postępy to na pewno ucieszy cię informacja, że potrafię prowadzić dziennik powtórek.

Za twoją zgodą mogę przesyłać jego anonimową wersję na stronę projektu.  W ten sposób nie tylko pomagasz mi stawać się coraz lepszym, ale też przyczyniasz się do rozwoju badań naukowych nad pamięcią długotrwałą.

Odznacz to pole wyboru jeśli nie wyrażasz zgody.</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>Przesyłaj anonimowe dane dziennika powtórek</translation>
    </message>
    <message>
        <source>(You can always change this setting later using the &apos;Configure Mnemosyne&apos; menu option.)</source>
        <translation>(Zawsze możesz dokonać zmiany tego ustawienia w menu opcji &quot;Ustawienia Mnemosyne&quot;.)</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statystyki</translation>
    </message>
    <message>
        <source>Now you&apos;re ready to start!
&lt;p&gt;
Add new cards by clicking on the icon with the &apos;plus&apos; sign in the top left.
&lt;p&gt;
Remember, there is no need to worry about saving your work, I will do so automatically.
&lt;p&gt;
For best results, I suggest you do your revisions every day, although I&apos;ll try to cope as best I can if you postpone your revisions or if you want to learn ahead of time.
&lt;p&gt;
For more documentation, see http://www.mnemosyne-proj.sourceforge.net.
&lt;p&gt;
Happy learning!</source>
        <translation>Możemy zaczynać!
&lt;p&gt;
Aby dodać nową kartę kliknij na ikonę plusa znajdującą się w lewym górnym rogu.
&lt;p&gt;
Pamiętaj, że wszelkie zmiany zapisuję automatycznie, więc nie musisz zaprzątać sobie tym głowy.
&lt;p&gt;
W celu osiągnięcia najlepszych rezultatów staraj się robić powtórki codziennie. Jednak jeśli przełożysz je na później lub powtórzysz przed czasem, to zrobię wszystko co w mojej mocy aby zapamiętywanie nadal było jak najefektywniejsze.
&lt;p&gt;
Aby uzyskać więcej informacji przejdź do witryny: http://www.mnemosyne-proj.sourceforge.net
&lt;p&gt;
Przyjemnej nauki!</translation>
    </message>
    <message>
        <source>Ready to start</source>
        <translation>Zaczynamy</translation>
    </message>
</context>
<context>
    <name>QTextEdit2</name>
    <message>
        <source>Insert &amp;image</source>
        <translation>Wstaw &amp;obraz</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Insert &amp;sound</source>
        <translation>Wstaw &amp;dźwięk</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>&amp;3-sided input</source>
        <translation>&amp;Karta podzielona na trzy części</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>Pliki obrazów</translation>
    </message>
    <message>
        <source>Insert image</source>
        <translation>Wstaw obraz</translation>
    </message>
    <message>
        <source>Sound files</source>
        <translation>Pliki dźwięków</translation>
    </message>
    <message>
        <source>Insert sound</source>
        <translation>Wstaw dźwięk</translation>
    </message>
</context>
<context>
    <name>StatisticsDlg</name>
    <message>
        <source>Scheduled cards for the next days:

</source>
        <translation>Ilość kart przeznaczonych do powtórki:

</translation>
    </message>
    <message>
        <source>In</source>
        <translation>W ciągu</translation>
    </message>
    <message>
        <source>day(s) :</source>
        <translation>dni(a) :</translation>
    </message>
    <message>
        <source>Number of cards with the following grades:

</source>
        <translation>Ilość kart, które otrzymały ocenę:

</translation>
    </message>
    <message>
        <source>Grade</source>
        <translation>Ocena</translation>
    </message>
    <message>
        <source>No current card.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation type="unfinished">Ocena:</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation type="unfinished">Łatwość:</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation type="unfinished">Powtórki:</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation type="unfinished">Pomyłki:</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation type="unfinished">Liczba dni, które upłynęły od ostatniej powtórki:</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation type="unfinished">Liczba dni pozostałych do rozpoczęcia powtórki:</translation>
    </message>
</context>
<context>
    <name>StatisticsFrm</name>
    <message>
        <source>Category</source>
        <translation>Kategoria</translation>
    </message>
    <message>
        <source>Cards</source>
        <translation>Kart</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statystyki</translation>
    </message>
    <message>
        <source>Schedule</source>
        <translation>Harmonogram</translation>
    </message>
    <message>
        <source>Grades</source>
        <translation>Oceny</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Kategorie</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Current card</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TipDlg</name>
    <message>
        <source>For optimal results, it&apos;s best to do your repetitions every day.</source>
        <translation>Aby osiągnąć najlepsze rezultaty staraj się robić powtórki codziennie.</translation>
    </message>
    <message>
        <source>If you&apos;ve been away for a few days, don&apos;t worry about your backlog. Do as many cards as you feel like to catch up, the rest will be automatically rescheduled to the future.</source>
        <translation>Nie musisz martwić się zaległościami jeśli program nie był uruchamiany przez dłuższy czas. Zaległe powtórki zostaną automatycznie wyświetlone w odpowiednim terminie w przyszłości.</translation>
    </message>
    <message>
        <source>The &apos;number of grade 0 cards to learn at once&apos; setting determines how many new cards you are trying to learn at the same time. It does &lt;b&gt;not&lt;/b&gt; tell you how many new cards you need to learn per day. You are the judge of that: you can learn more cards or less cards, depending on how you feel.</source>
        <translation>Opcja &quot;Ilość przeznaczonych do zapamiętania kart, które otrzymały ocenę 0&quot; określa ilość kart przeznaczonych do nauki w tym samym czasie. &lt;b&gt;Nie&lt;/b&gt; jest to ilość kart przeznaczonych do nauki dziennie, gdyż jest ona dowolna i zależna od twoich chęci.</translation>
    </message>
    <message>
        <source>In summary, try to do your repetitions every day, but don&apos;t worry too much about getting the &apos;scheduled&apos; counter to zero, and certainly not about getting the &apos;Not memorised&apos; counter to zero.</source>
        <translation>Podsumujmy wszystkie rady: pamiętaj aby powtórki wykonywać codziennie i nie przejmuj się jeśli wskaźniki &quot;zaplanowanych&quot; oraz &quot;niezapamiętanych&quot; nadal wyświetlają pewną liczbę nie przyswojonych informacji. Ich przeznaczeniem jest informować, a nie zmuszać do dalszej nauki, która zależy tylko i wyłącznie od twoich chęci. </translation>
    </message>
    <message>
        <source>Grade 1 cards are different from grade 0 cards in the sense that they show up less often and are not subject to the &apos;number of grade 0 cards to learn at once&apos; setting.</source>
        <translation>Karty, które otrzymały ocenę 1 różnią się od kart ocenionych na 0 tym, że pokazują się rzadziej i nie podlegają regule ustawienia &quot;ilość kart przeznaczonych do zapamiętania w tym samym czasie&quot;.</translation>
    </message>
    <message>
        <source>You can use keyboard shortcuts to do your repetitions. Enter, Return or Space stand for the default action (&apos;Show answer&apos; or &apos;grade 4&apos;). The number keys can be used for grading.</source>
        <translation>Podczas powtórek możesz korzystać ze skrótów klawiszowych. Naciśnięcie klawiszy Enter, Return oraz Spacja powoduje wykonanie podstawowej czynności, takiej jak &quot;Pokaż odpowiedź&quot; lub &quot;ocena 4&quot;, natomiast klawisze numeryczne odpowadają poszczególnym ocenom.</translation>
    </message>
    <message>
        <source>You can select the categories you wish to study in the &apos;Activate categories&apos; menu option.</source>
        <translation>Możesz dokonać wyboru kategorii których chcesz się uczyć za pomocą opcji &quot;Aktywuj kategorie&quot;.</translation>
    </message>
    <message>
        <source>It is recommended to put all your cards in a single database and use categories to organise them. Using &apos;Activate categories&apos; is much more convenient than have to load and unload several databases.</source>
        <translation>Zaleca się trzymanie wszystkich kart w jednej bazie danych i ogranizowanie ich przy pomocy kategorii, ponieważ jest to dużo prostsze od ciągłego wczytywania i zapisywania wielu baz danych.</translation>
    </message>
    <message>
        <source>You can import cards in a wide variety of formats: tab delimited txt files, Supermemo files, ... .</source>
        <translation>Importować można karty zapisane w wielu formatach plików takich jak plik tekstowy rodzielany znakami tabulacji, plik programu Supermemo i inne.</translation>
    </message>
    <message>
        <source>If you have cards in Word or Excel, export them to tab delimited txt files with UTF-8 unicode encoding to be able to import them into Mnemosyne.</source>
        <translation>Aby importować karty w formacie Word lub Excel uprzednio zapisz je jako&quot;tekst rozdzielany znakami tabulacji&quot; z kodowaniem UTF-8.</translation>
    </message>
    <message>
        <source>If you want to print out your cards, export them to a txt file which you can then print from your favourite Word processor.</source>
        <translation>Aby wydrukować karty wyeksportuj je jako plik tekstowy, który następnie otwórz i wydrukuj za pomocą ulubionego edytora tekstu.</translation>
    </message>
    <message>
        <source>You can share your cards with someone else by exporting them to XML and choosing the &apos;Reset learning data&apos; option on export.</source>
        <translation>Aby dzielić się swoimi kartami z innymi, wyeksportuj je do pliku XML zaznaczając opcję &quot;Usuń dane dotyczące powtórek&quot;.</translation>
    </message>
    <message>
        <source>If you study a foreign language with a different script, the default font size is sometimes a bit small. If you want to increase the size of these characters but keep the size of English text, use the &apos;increase size of non-latin characters by X points&apos; option.</source>
        <translation>Jeśli uczysz się języka obcego, którego litery różnią się znacznie od dotychczas ci znanych, domyślna czcionka może okazać się nieczytelna. Aby zwiększyć rozmiar znaków języka którego się uczysz jednocześnie zachowujac rozmiar angielskich liter, zaznacz opcję &quot;zwiększ rozmiar znaków innych niż łaciskie o X punktów&quot;.</translation>
    </message>
    <message>
        <source>You can add images and sounds to your cards. Right-click on the question or answer field when editing a card to bring up a pop-up menu to do so.</source>
        <translation>Podczas edycji karty możesz dodawać pliki graficzne oraz dzwięki poprzez kliknięcie prawym przyciskiem myszy na polu pytania lub odpowiedzi i wybranie odpowiedniej opcji w menu podręcznym.</translation>
    </message>
    <message>
        <source>It is recommended to keep your sound and image files inside your .mnemosyne directory. That way, it&apos;s easier to transfer your data between different computers.</source>
        <translation>Przenoszenie danych między komputerami staje się o wiele łatwiejsze jeśli pliki graficzne oraz dzwięki zapisywane są i przechowywane wewnątrz katalogu .mnemosyne.</translation>
    </message>
    <message>
        <source>When adding a three-sided card, two regular cards will be created. One with as question the written form and as answer the pronunciation and the translation, and one with as question the translation and as answer the written form and the pronunciation.</source>
        <translation>Podczas dodawania karty podzielonej na trzy części dodawane są do bazy dwie zwykłe karty. W pierwszej z nich jako pytanie służy informacja na temat formy pisemnej, na które odpowiedzią jest jej wymowa oraz tłumaczenie. W drugiej karcie jako pytanie służy informacja na temat tłumaczenia, a odpowiedzią na nie jest jego forma pisemna i wymowa.</translation>
    </message>
    <message>
        <source>You can use basic HTML tags in your cards to control their appearance.</source>
        <translation>Wygląd kart może być zmieniany za pomocą podstawowych znaczników HTML.</translation>
    </message>
    <message>
        <source>Mnemosyne can use LaTeX to render mathematical formulas, e.g. &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. (For this, you need LaTeX and dvipng installed.)</source>
        <translation>Mnemosyne może wykorzystywać oprogramowanie LaTeX do zapisywania równań matematycznych takich jak &lt;$&gt;x^2+y^2=z^2&lt;/$&gt; (Aby było to możliwe należy uprzednio zainstalować zarówno &quot;LaTeX&quot; jaki i &quot;dvipng&quot;).</translation>
    </message>
    <message>
        <source>The best way to backup your data is to copy your .mnemosyne directory (if you follow the recommended procedure to keep all your files there) and move it to a different drive. Mnemosyne keeps automatic XML-based backups in .mnemosyne/backups, but that won&apos;t help you if that drive dies... </source>
        <translation>Mnemosyne automatycznie wykonuje kopię zapasową bazy danych i umieszcza ją w katalogu .mnemosyne/backups, jednak w razie uszkodzenia dysku procedura ta nie chroni przed utratą danych. Dlatego zalecane jest wykonywanie kopii zapasowej poprzez skopiowanie folderu .mnemosyne na inny nośnik (jeśli wszystkie pliki powiązane z bazą przechowywane są w katalogu głównym programu wystarczy tylko go skopiować w porządane miejsce) </translation>
    </message>
    <message>
        <source>You can run Mnemosyne from a USB key. Copy C:\Program Files\Mnemosyne to your USB key, and then copy the .mnemosyne directory from your home directory to inside the Mnemosyne directory on the USB key.</source>
        <translation>Aby uruchomić program Mnemosyne z dysku USB skopiuj folder C:\Program Files\Mnemosyne na dysk USB a następnie umieść w nim katalog .mnemosyne, który znajduje się na komputerze.</translation>
    </message>
    <message>
        <source>If you use Mnemosyne on multiple computers, there is a handy tool called Unison to help you synchronise your data. See the Mnemosyne website for more information.</source>
        <translation>Dla osób, które korzystają z programu Mnemosyne na wielu komputerach przygotowano specjalny program &quot;Unision&quot; mający na celu ułatwienie procesu synchronizacji danych. Więcej szczegółów znajduje się na stronie Mnemosyne.</translation>
    </message>
    <message>
        <source>You can sort the cards in the &apos;Edit Deck&apos; dialog by answer or by category by clicking on the corresponding column title. Clicking again changes the sort order.</source>
        <translation>W oknie &quot;Edytuj zestaw kart&quot; można sortować dane według odpowiedzi lub kategorii klikając na odpowiednią nazwę kolumny. Ponowne kliknięcie zmienia kolejność sortowania elementów.</translation>
    </message>
    <message>
        <source>If you want more fine-grained control over LaTeX&apos;s behaviour, see the explanation of the &lt;$$&gt;...&lt;/$$&gt; and &lt;latex&gt;...&lt;/latex&gt; tags on Mnemosyne&apos;s website.</source>
        <translation>Bardziej zaawansowane polecenia programu LaTeX dostępne są za pomocą znaczników &lt;$$&gt;...&lt;/$$&gt; oraz &lt;latex&gt;...&lt;/latex&gt; i zostały szczegółowo omówione na stronie Mnemosyne.</translation>
    </message>
    <message>
        <source>Advanced users can customise more of Mnemosyne by editing the config.py file in their .mnemosyne directory. They can also install plugins to customise Mnemosyne even further.</source>
        <translation>Zaawansowani użytkownicy Mnemosyne mogą dostosowywać program do swoich potrzeb poprzez instalację dodatkowych wtyczek lub edycję znajdującego się w katalogu .mnemosyne pliku konfiguracyjnego &quot;config.spy&quot;.</translation>
    </message>
</context>
<context>
    <name>TipFrm</name>
    <message>
        <source>Tip of the day</source>
        <translation>Porada dnia</translation>
    </message>
    <message>
        <source>&lt;b&gt;Did you know...?&lt;/b&gt;</source>
        <translation>&lt;b&gt;Czy wiesz, że...?&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&amp;Show tips on startup</source>
        <translation>&amp;Pokazuj porady podczas uruchamiania programu</translation>
    </message>
    <message>
        <source>Alt+S</source>
        <translation>Alt+S</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation>&amp;Poprzednia</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Następna</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
</TS>
